NMCCA Opinion Archive 2014 | U.S. Navy JAG Corps
Description: The Navy Judge Advocate General’s Corps provides solutions, from a military perspective, to legal issues involving military operations, organization, and personnel, wherever and whenever such solutions are required, with primary focus on operations, accountability, Sailor legal readiness, and Navy legal readiness.
Keywords: military lawyer,military attorney,court martial lawyers,court-martial,courts-martial,defense lawyer military,awol,divorce,drug defense,military records,Navy JAG, JAG, Legalmen, Legalman, JAGC, OJAG, NLSO, TSO, RLSO

## Courts

## | NMCCA Decisions (Court Opinions)

This section contains the decisions of the Court based upon their chronological release date. Published opinions are binding in the Naval Services at the trial level and at this Court. Unpublished opinions may be cited as persuasive authority.

### Browse Archives

1. 2014 Archive
2. 2013 Archive
3. 2012 Archive
4. 2011 Archive
5. 2010 Archive
6. 2009 Archive

1. 2008 Archive
2. 2007 Archive
3. 2006 Archive
4. 2005 Archive
5. 2004 Archive

## 2014 Opinion Archive

#### Directions:

To aid your search for information within the archive, the table below has a few key features:

- Table Sort: Click on a column heading to sort the table by that column.
- Highlight: Click on any row to highlight the information.
- Search: You can search any column for specific information. Choose a column name in the drop down box, enter your query and click the Search button. You can clear the search results using the Rest button.

Parties | Docket # | Date | File | Type
--- | --- | --- | --- | ---
U.S. v. CAIN | 201300392 | 09/11/2014 | Download | Per Curiam
U.S. v. CUFF | 201400252 | 09/11/2014 | Download | Summary Disposition
U.S. v. NATARENO | 201400225 | 09/11/2014 | Download | Summary Disposition
U.S. v. KARANJA | 201400202 | 09/11/2014 | Download | Summary Disposition
U.S. v. CHATMAN | 201300119 | 08/28/2014 | Download | Per Curiam
U.S. v. MORRIS | 201300348 | 08/28/2014 | Download | Per Curiam
U.S. v. ROCKENHAUS | 201300409 | 08/28/2014 | Download | Per Curiam
U.S. v. SEWELL | 201300432 | 08/28/2014 | Download | Per Curiam
U.S. v. TORRES | 201300396 | 08/28/2014 | Download | Authored
U.S. v. WILSON, JR. | 201300315 | 08/28/2014 | Download | Per Curiam
U.S. v. GIBSON | 201400114 | 08/28/2014 | Download | Summary Disposition
U.S. v. LINTON | 201400157 | 08/28/2014 | Download | Summary Disposition
U.S. v. DELMONTE JR. | 201400175 | 08/28/2014 | Download | Summary Disposition
U.S. v. TAPIO | 201400178 | 08/28/2014 | Download | Summary Disposition
U.S. v. VERWEY | 201400180 | 08/28/2014 | Download | Summary Disposition
U.S. v. BOTLEY | 201400186 | 08/28/2014 | Download | Summary Disposition
U.S. v. HERZOG | 201400204 | 08/28/2014 | Download | Summary Disposition
U.S. v. GREEN | 201400219 | 08/28/2014 | Download | Summary Disposition
U.S. v. MENDOZA | 201400236 | 08/28/2014 | Download | Summary Disposition
U.S. v. CHAVIRA | 201400239 | 08/28/2014 | Download | Summary Disposition
U.S. v. SILVERSTRAND | 201400179 | 08/28/2014 | Download | Summary Disposition
U.S. v. WORLEY | 201400189 | 08/28/2014 | Download | Summary Disposition
U.S. v. MCKENZIE | 201400190 | 08/28/2014 | Download | Summary Disposition
U.S. v. SOPOCI | 201400197 | 08/28/2014 | Download | Summary Disposition
U.S. v. WILSON JR. | 201400214 | 08/28/2014 | Download | Summary Disposition
U.S. v. OLIVAREZ | 201400223 | 08/26/2014 | Download | Summary Disposition
U.S. v. POTTMEYER | 201300293 | 08/26/2014 | Download | Per Curiam
U.S. v. CLARK | 201400221 | 08/26/2014 | Download | Summary Disposition
U.S. v. NEIDERT | 201400050 | 08/26/2014 | Download | Summary Disposition
U.S. v. SMITH | 201400106 | 08/21/2014 | Download | Per Curiam
U.S. v. SOLOMON | 201100582 | 08/21/2014 | Download | Per Curiam
U.S. v. MILES | 201300272 | 08/21/2014 | Download | Authored
U.S. v. RAINES | 201400027 | 08/21/2014 | Download | Authored
U.S. v. JOURAVSKA | 201300251 | 08/19/2014 | Download | Per Curiam
U.S. v. HART | 201300295 | 08/19/2014 | Download | Authored
U.S. v. LYNCH | 201300387 | 08/19/2014 | Download | Per Curiam
U.S. v. AGUINALDO | 201400183 | 08/19/2014 | Download | Summary Disposition
U.S. v. MEDINA | 201400167 | 08/19/2014 | Download | Summary Disposition
U.S. v. MORIARTY | 201400182 | 08/14/2014 | Download | Summary Disposition
U.S. v. HASLEY | 201400026 | 08/14/2014 | Download | Summary Disposition
U.S. v. CALDWELL | 201000557 | 08/12/2014 | Download | Per Curiam
U.S. v. WILDER, JR. | 201400118 | 08/12/2014 | Download | Per Curiam
U.S. v. ROSARIO | 201400176 | 07/31/2014 | Download | Summary Disposition
U.S. v. SALAZAR III | 201400145 | 07/31/2014 | Download | Summary Disposition
U.S. v. MCNEAL | 201400121 | 07/31/2014 | Download | Summary Disposition
U.S. v. WEIR | 201400094 | 07/31/2014 | Download | Summary Disposition
U.S. v. MANGUM | 201400062 | 07/31/2014 | Download | Summary Disposition
U.S. v. ZAMORA | 201400191 | 07/31/2014 | Download | Summary Disposition
U.S. v. YOUNG, JR. | 201200135 | 07/31/2014 | Download | Summary Disposition
U.S. v. FERRERA | 201400130 | 07/31/2014 | Download | Summary Disposition
U.S. v. ARTAP | 201400138 | 07/31/2014 | Download | Summary Disposition
U.S. v. SEITZ | 201400148 | 07/31/2014 | Download | Summary Disposition
U.S. v. TEFFT | 201400166 | 07/31/2014 | Download | Summary Disposition
U.S. v. LEWIS | 201300464 | 07/31/2014 | Download | Summary Disposition
U.S. v. AGUILAR | 201300464 | 07/31/2014 | Download | Per Curiam
U.S. v. ELLERBEE | 201300109 | 07/31/2014 | Download | Authored
U.S. v. ENGLER | 201300365 | 07/31/2014 | Download | Per Curiam
U.S. v. GREEN | 201300276 | 07/31/2014 | Download | Authored
U.S. v. HAINS | 201300477 | 07/31/2014 | Download | Per Curiam
U.S. v. MAPLES | 201300448 | 07/31/2014 | Download | Per Curiam
U.S. v. SPRATLING | 201400060 | 07/31/2014 | Download | Per Curiam
U.S. v. WARD, JR. | 201400021 | 07/31/2014 | Download | Per Curiam
U.S. v. EPPS | 201300423 | 07/29/2014 | Download | Per Curiam
U.S. v. EVANS | 201300248 | 07/29/2014 | Download | Per Curiam
U.S. v. WORKMAN | 201400080 | 07/29/2014 | Download | Per Curiam
U.S. v. CAPTAIN | 201300137 | 07/29/2014 | Download | Per Curiam
U.S. v. SLOAN | 201400134 | 07/29/2014 | Download | Summary Disposition
U.S. v. AUTOLINO | 201400154 | 07/29/2014 | Download | Summary Disposition
U.S. v. SMITH | 201300401 | 07/24/2014 | Download | Per Curiam
U.S. v. FLOWERS | 201400003 | 07/24/2014 | Download | Per Curiam
U.S. v. TURNER | 201400036 | 07/22/2014 | Download | Per Curiam
U.S. v. SNEARL | 201300446 | 07/22/2014 | Download | Per Curiam
U.S. v. WATTS | 201400128 | 07/22/2014 | Download | Per Curiam
U.S. v. MCCRAY | 201300390 | 07/22/2014 | Download | Per Curiam
U.S. v. LOPEZ | 201300394 | 07/22/2014 | Download | Per Curiam
U.S. v. HATCH | 201400011 | 07/22/2014 | Download | Per Curiam
U.S. v. GODOY | 201400163 | 07/15/2014 | Download | Summary Disposition
U.S. v. SILVA | 201400160 | 07/15/2014 | Download | Summary Disposition
U.S. v. HARRISON | 201300454 | 06/17/2014 | Download | Summary Disposition
U.S. v. LACOUNT | 201300259 | 06/19/2014 | Download | Per Curiam
U.S. v. BOCCIA | 201400078 | 06/26/2014 | Download | Summary Disposition
U.S. v. MARSH | 201400090 | 06/26/2014 | Download | Summary Disposition
U.S. v. THAI | 201400084 | 06/26/2014 | Download | Summary Disposition
U.S. v. TURMAN | 201400123 | 06/26/2014 | Download | Summary Disposition
U.S. v. BROWN | 201400091 | 06/26/2014 | Download | Summary Disposition
U.S. v. ELDRIDGE, JR. | 201400065 | 06/26/2014 | Download | Summary Disposition
U.S. v. DELUCA IV | 201400058 | 06/26/2014 | Download | Summary Disposition
U.S. v. RICHMOND | 201400051 | 06/26/2014 | Download | Summary Disposition
U.S. v. CUMMINGS | 201400095 | 06/26/2014 | Download | Per Curiam
U.S. v. CIESLEWICZ | 201300421 | 06/26/2014 | Download | Per Curiam
U.S. v. REDMON | 201300077 | 06/26/2014 | Download | Authored
U.S. v. WOODS | 201300153 | 06/26/2014 | Download | Authored
U.S. v. EVANS | 201300174 | 06/26/2014 | Download | Authored
U.S. v. LANE | 201300479 | 06/30/2014 | Download | Per Curiam
U.S. v. JANUSKI | 201300210 | 06/30/2014 | Download | Per Curiam
U.S. v. CORTEZ | 201300462 | 06/30/2014 | Download | Per Curiam
U.S. v. BROWN | 201300252 | 06/30/2014 | Download | Per Curiam
U.S. v. LAWSON | 201300294 | 06/30/2014 | Download | Per Curiam
U.S. v. BROWN | 201300181 | 06/30/2014 | Download | Authored
U.S. v. SANCHEZ III | 201400053 | 06/30/2014 | Download | Per Curiam
U.S. v. KISH | 201100404 | 06/16/2014 | Download | Authored
U.S. v. SINE | 201400081 | 6/10/2014 | Download | Summary Disposition
U.S. v. STEELE | 201400029 | 5/29/2014 | Download | Summary Disposition
U.S. v. WOLSKI | 201400083 | 5/29/2014 | Download | Summary Disposition
U.S. v. ANDRUS | 201400089 | 5/29/2014 | Download | Summary Disposition
| U.S. v. VILTZ | 201400092 | 5/29/2014 | Download | Summary Disposition
U.S. v. CONSER | 201400099 | 5/29/2014 | Download | Summary Disposition
U.S. v. HO | 201400129 | 5/29/2014 | Download | Summary Disposition
U.S. v. TRAMMELL | 201400131 | 5/29/2014 | Download | Summary Disposition
U.S. v. DANLEY III | 201400146 | 5/29/2014 | Download | Summary Disposition
U.S. v. MALDONADO | 201400149 | 5/29/2014 | Download | Summary Disposition
U.S. v. MCMAHAN | 201400164 | 5/29/2014 | Download | Summary Disposition
U.S. v. COLE | 201300165 | 5/29/2014 | Download | Per Curiam
U.S. v. DUNTON | 201300148 | 5/29/2014 | Download | Authored
U.S. v. FENDER | 201300334 | 5/29/2014 | Download | Per Curiam
U.S. v. SIMMERMACHER | 201300129 | 5/29/2014 | Download | Authored
U.S. v. STONER | 201300217 | 5/29/2014 | Download | Per Curiam
U.S. v. SULLIVAN | 201400071 | 5/29/2014 | Download | Per Curiam
U.S. v. GONZALEZ | 201300405 | 5/27/2014 | Download | Summary Disposition
U.S. v. BECERRA | 201400077 | 5/27/2014 | Download | Summary Disposition
U.S. v. YOUNG-SHINAULT | 201400079 | 5/27/2014 | Download | Summary Disposition
U.S. v. MCCLAIN | 201400101 | 5/27/2014 | Download | Summary Disposition
U.S. v. CASTILLO | 201300280 | 5/27/2014 | Download | Authored
U.S. v. ELEFTHERATES | 201400142 | 5/27/2014 | Download | Per Curiam
U.S. v. HOWELL | 201200264 | 5/22/14 | Download | Authored
U.S. v. GRIFFIN | 201300227 | 5/20/14 | Download | Per Curiam
U.S. v. SOOTOO | 201400109 | 5/20/14 | Download | Summary Disposition
U.S. v. DRAYTON | 201400085 | 5/8/14 | Download | Summary Disposition
U.S. v. CASA | 201400075 | 5/8/14 | Download | Summary Disposition
U.S. v. SCHMIDT | 201400073 | 5/8/14 | Download | Summary Disposition
U.S. v. FREEMAN III | 201300102 | 4/30/2014 | Download | Authored
U.S. v. HAAG | 201300447 | 4/30/2014 | Download | Summary Disposition
U.S. v. NELSON | 201300467 | 4/30/2014 | Download | Summary Disposition
U.S. v. BUIE | 201300478 | 4/30/2014 | Download | Summary Disposition
U.S. v. RABINO | 201300483 | 4/30/2014 | Download | Summary Disposition
U.S. v. LOPEZ | 201400013 | 4/30/2014 | Download | Summary Disposition
U.S. v. MCLAUGHLIN II | 201400040 | 4/30/2014 | Download | Summary Disposition
U.S. v. KINYANJUI | 201400055 | 4/30/2014 | Download | Summary Disposition
U.S. v. DAVIS | 201400112 | 4/30/2014 | Download | Summary Disposition
U.S. v. MASON | 201300154 | 4/30/2014 | Download | Per Curiam
U.S. v. ONG | 201300484 | 4/30/2014 | Download | Summary Disposition
U.S. v. CHANG | 201400012 | 4/30/2014 | Download | Summary Disposition
U.S. v. YARUSHIN | 201400018 | 4/30/2014 | Download | Summary Disposition
U.S. v. RAZA | 201400054 | 4/30/2014 | Download | Summary Disposition
U.S. v. DENGLER | 201400064 | 4/30/2014 | Download | Summary Disposition
U.S. v. LEDESMA | 201400086 | 4/30/2014 | Download | Summary Disposition
U.S. v. EDGINTON | 201300328 | 4/30/2014 | Download | Per Curiam
U.S. v. HEDRICK | 201300438 | 4/24/2014 | Download | Summary Disposition
U.S. v. BEDFORD | 201400052 | 4/24/2014 | Download | Summary Disposition
U.S. v. OROZCO | 201400104 | 4/24/2014 | Download | Summary Disposition
U.S. v. HENDERSON | 201300140 | 4/24/14 | Download | Per Curiam
U.S. v. CLARK | 201300411 | 4/24/14 | Download | Per Curiam
U.S. v. SAMUEL | 201400045 | 4/24/14 | Download | Summary Disposition
U.S. v. GOMEZ | 201300428 | 4/24/14 | Download | Summary Disposition
U.S. v. DICKENS | 201300025 | 4/22/14 | Download | Authored
U.S. v. NIEVES | 201400047 | 4/22/14 | Download | Summary Disposition
U.S. v. LLOYD | 201300487 | 4/22/14 | Download | Summary Disposition
U.S. v. SHIELDS | 201400025 | 4/22/14 | Download | Per Curiam
U.S. v. RIVAS | 201400137 | 4/17/14 | Download | Summary Disposition
U.S. v. LEONE | 201400032 | 4/17/14 | Download | Summary Disposition
U.S. v. WHITE | 201300474 | 4/17/14 | Download | Summary Disposition
U.S. v. HILL, JR. | 201300453 | 3/31/14 | Download | Summary Disposition
U.S. v. HERZOG | 201400063 | 4/8/14 | Download | Summary Disposition
U.S. v. GRANADOS | 201300475 | 4/8/14 | Download | Summary Disposition
U.S. v. BARON | 201300449 | 3/31/14 | Download | Summary Disposition
U.S. v. NICHOLAS | 201400038 | 3/31/14 | Download | Summary Disposition
U.S. v. WAUGH,JR | 201300465 | 3/31/14 | Download | Summary Disposition
U.S. v. BRENNEMAN | 201400028 | 3/31/14 | Download | Summary Disposition
U.S. v. HINTZE | 201400049 | 3/31/14 | Download | Summary Disposition
U.S. v. PRESNELL | 201400041 | 3/31/14 | Download | Summary Disposition
U.S. v. MARROWBONE | 201400034 | 3/31/14 | Download | Summary Disposition
U.S. v. JONES | 201300349 | 3/31/14 | Download | Per Curiam
U.S. v. RUSSELL | 201300208 | 3/31/14 | Download | Per Curiam
U.S. v. HOLMES | 201400019 | 3/27/2014 | Download | Summary Disposition
U.S. v. IPINA | 201400035 | 3/27/2014 | Download | Summary Disposition
U.S. v. JIMENEZ | 201300264 | 3/27/14 | Download | Summary Disposition
U.S. v. WISE | 201300466 | 3/27/14 | Download | Summary Disposition
U.S. v. LOIACONO | 201200451 | 3/27/14 | Download | Authored
U.S. v. DOCTOR | 201300187 | 3/27/14 | Download | Authored
U.S. v. SMITH | 201300223 | 3/27/14 | Download | Per Curiam
U.S. v. DENOBRIGA | 201300168 | 3/27/14 | Download | Per Curiam
U.S. v. RAMIREZ-EMPUNO | 201300190 | 3/27/14 | Download | Per Curiam
U.S. v. MARIN | 201300443 | 3/27/14 | Download | Summary Disposition
U.S. v. BAIN | 201400037 | 3/27/14 | Download | Summary Disposition
U.S. v. VIGIL | 201300468 | 3/27/14 | Download | Summary Disposition
U.S. v. LUNG | 201300455 | 3/27/14 | Download | Summary Disposition
U.S. v. WITTE | 201300414 | 3/27/14 | Download | Summary Disposition
U.S. v. TORRES | 201300429 | 3/25/14 | Download | Summary Disposition
U.S. v. POST | 201300189 | 3/25/14 | Download | Per Curiam
U.S. v. MOORE | 201400001 | 3/20/2014 | Download | Summary Disposition
U.S. v. BLACK | 201300292 | 3/20/14 | Download | Per Curiam
U.S. v. MCALLISTER | 201300086 | 3/20/14 | Download | Per Curiam
U.S. v. PACE-BATES | 201300482 | 3/13/14 | Download | Summary Disposition
U.S. v. BOYD | 201300302 | 3/13/14 | Download | Summary Disposition
U.S. v. TAYLOR | 201300195 | 3/6/14 | Download | Per Curiam
U.S. v. JILES | 201200062 | 3/6/14 | Download | Authored
U.S. v. KUHN | 201400015 | 2/28/14 | Download | Summary Disposition
U.S. v. HARTRICK | 201300440 | 2/28/14 | Download | Summary Disposition
U.S. v. DOREMUS | 201300461 | 2/28/14 | Download | Summary Disposition
U.S. v. VARGAS | 201300426 | 2/28/14 | Download | Authored
U.S. v. BELL | 201200517 | 2/28/14 | Download | Per Curiam
U.S. v. BAKER | 201300402 | 2/28/14 | Download | Per Curiam
U.S. v. YORK | 201300287 | 2/28/14 | Download | Per Curiam
U.S. v. DUTTA | 201300254 | 2/28/14 | Download | Per Curiam
U.S. v. BROWN | 201300340 | 2/28/14 | Download | Per Curiam
U.S. v. SIMPSON | 201300418 | 2/28/14 | Download | Summary Disposition
U.S. v. ROBINSON III | 201300476 | 2/28/14 | Download | Summary Disposition
U.S. v. LEGASSEY | 201400017 | 2/28/14 | Download | Summary Disposition
U.S. v. LANGE | 201400010 | 2/28/14 | Download | Summary Disposition
U.S. v. CHRASTINA | 201200464 | 2/25/14 | Download | Per Curiam
U.S. v. GRIER | 201300445 | 2/25/14 | Download | Summary Disposition
U.S. v. CARULLI | 201300451 | 2/25/14 | Download | Summary Disposition
U.S. v. SALCIDO | 201300143 | 2/20/14 | Download | Per Curiam
U.S. v. NORMAN | 201300152 | 2/20/14 | Download | Per Curiam
U.S. v. BUEHLER | 201300389 | 2/20/14 | Download | Per Curiam
U.S. v. ALDONIS | 201300306 | 2/20/14 | Download | Per Curiam
U.S. v. VAZQUEZ | 201300412 | 2/20/14 | Download | Summary Disposition
U.S. v. TRUJILLO | 201300361 | 2/20/14 | Download | Summary Disposition
U.S. v. SHEPHERD | 201300371 | 2/20/14 | Download | Summary Disposition
U.S. v. WILSON | 201300370 | 2/11/14 | Download | Summary Disposition
U.S. v. ANTONIO | 201300417 | 2/11/14 | Download | Summary Disposition
U.S. v. COLE | 201300318 | 1/31/14 | Download | Per Curiam
U.S. v. WHITE | 201300115 | 1/31/14 | Download | Authored
U.S. v. EASTERLY | 201300067 | 1/31/14 | Download | Authored
U.S. v. DURAN | 201200440 | 1/31/14 | Download | Authored
U.S. v. CUSTER | 201300362 | 1/31/14 | Download | Summary Disposition
U.S. v. VEGA | 201300372 | 1/31/14 | Download | Summary Disposition
U.S. v. NOBLE | 201300406 | 1/31/14 | Download | Summary Disposition
U.S. v. EALEY | 201300415 | 1/31/14 | Download | Summary Disposition
U.S. v. HENSLEY | 201300434 | 1/31/14 | Download | Summary Disposition
U.S. v. HALL | 201300435 | 1/31/14 | Download | Summary Disposition
U.S. v. AGOSTOBAEZ | 201300444 | 1/31/14 | Download | Summary Disposition
U.S. v. NASH | 201000220 | 1/30/14 | Download | Summary Disposition
U.S. v. HOWARD | 201300289 | 1/30/14 | Download | Summary Disposition
U.S. v. NAJDAWI | 201300298 | 1/30/14 | Download | Summary Disposition
U.S. v. DIAZHERRERA | 201300351 | 1/30/14 | Download | Summary Disposition
U.S. v. GREEN | 201300363 | 1/30/14 | Download | Summary Disposition
U.S. v. COUNCIL | 201300368 | 1/30/14 | Download | Summary Disposition
U.S. v. HERNANDEZ | 201300373 | 1/30/14 | Download | Summary Disposition
U.S. v. HOLIFIELD | 201300382 | 1/30/14 | Download | Summary Disposition
U.S. v. MCMURRY | 201300398 | 1/30/14 | Download | Summary Disposition
U.S. v. HENES | 201300439 | 1/30/14 | Download | Summary Disposition
U.S. v. BREMER | 201200472 | 1/23/14 | Download | Summary Disposition
U.S. v. PIATTI | 201300316 | 1/23/14 | Download | Per Curiam
U.S. v. POST | 201300189 | 1/23/14 | Download | Per Curiam
U.S. v. MAZA | 201300297 | 1/22/14 | Download | Published
U.S. v. LAING | 201300395 | 1/16/14 | Download | Per Curiam
U.S. v. WISE | 201300192 | 1/16/14 | Download | Per Curiam
U.S. v. FLOYD | 201300424 | 1/14/14 | Download | Summary Disposition
U.S. v. CRAWFORD | 201300285 | 1/14/14 | Download | Authored
U.S. v. VALENTIN | 201000683 | 1/14/14 | Download | Per Curiam

### Navigate the NMCCA

- NMCCA
- Opinion Archive
- Oral Arguments
- Digest
- History

If the information you are looking for is not available here, you may submit a FOIA Request.

### Contact NMCCA HQ

Mailing Address:
  Navy-Marine Corps Court of Criminal Appeals (Code 51)
  United States Navy
  1254 Charles Morris St., SE
  Suite 320
  Washington Navy Yard, DC 20374-5124
Phone Numbers:
  Comm: (202) 685-7700
  DSN: 325-7700
  Fax: (202) 685-7690
Hours:
  0730 – 1630
  Monday – Friday